@@ -1,6 +1,5 @@
 import datetime
 import logging
-import codecs
 import os
 import sys
 import time
@@ -41,10 +40,7 @@ from dsmigrator.policies import (
 from dsmigrator.proxy import proxy_edit
 from dsmigrator.system_settings import settings_transfer
 from dsmigrator.tasks import ebt_listmaker, st_listmaker
-
-install()
-
-console = Console()
+from dsmigrator.logging import *
 
 
 def ascii_art():
@@ -76,13 +72,6 @@ def ascii_art():
     )
 
 
-ascii_art()
-console.print(
-    "Welcome to the Trend Micro Policy Migration Tool",
-    style="bold red",
-)
-
-
 class Logger(object):
     def flush(self):
         pass
@@ -90,6 +79,7 @@ class Logger(object):
     def __init__(self):
         self.terminal = sys.stdout
         filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
+        # self.log = open(f"./{filename}", "a")
         self.log = open(f"./{filename}", "a", encoding="utf-8")
 
     def write(self, message):
@@ -116,22 +106,17 @@ def CommandWithConfigFile(config_file_param_name):
 
 
 def validate_api_keys(ctx, param, api_key):
-    try:
-        last_equal = api_key[-1] == "="
-        first_validation_bit = api_key.split("-")
-        last_validation_bit = first_validation_bit[4].split(":")
-        clean_list = [i for i in first_validation_bit[0:4]]
-        clean_list.append(last_validation_bit[0])
-        validate_list = [len(i) for i in clean_list]
-        validate_list.append(last_equal)
+    last_equal = api_key[-1] == "="
+    first_validation_bit = api_key.split("-")
+    last_validation_bit = first_validation_bit[4].split(":")
+    clean_list = [i for i in first_validation_bit[0:4]]
+    clean_list.append(last_validation_bit[0])
+    validate_list = [len(i) for i in clean_list]
+    validate_list.append(last_equal)
 
-        if validate_list == [8, 4, 4, 4, 12, True]:
-            return api_key
-        else:
-            raise click.BadParameter(
-                "Invalid API key format, please double-check the input."
-            )
-    except IndexError:
+    if validate_list == [8, 4, 4, 4, 12, True]:
+        return api_key
+    else:
         raise click.BadParameter(
             "Invalid API key format, please double-check the input."
         )
@@ -207,8 +192,8 @@ def main(
     delete_policies,
 ):
     """Moves your on-prem DS deployment to the cloud!"""
-    sys.stdout = Logger()
-    sys.stderr = sys.stdout
+    # sys.stdout = Logger()
+    # sys.stderr = sys.stdout
     OLD_API_KEY = original_api_key
     OLD_HOST = original_url
     NEW_API_KEY = cloud_one_api_key
@@ -350,5 +335,11 @@ def main(
 
 
 if __name__ == "__main__":
-    # os.environ["PYTHONIOENCODING"] = "utf-8"
+    filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
+    ascii_art()
+    console.print(
+        "Welcome to the Trend Micro Policy Migration Tool",
+        style="bold red",
+    )
     main()  # pylint: disable=no-value-for-parameter
+    console.save_text(filename)
