@@ -5,7 +5,9 @@ from time import sleep
 import requests
 import urllib3
 import json
+from dsmigrator.logging import console
 from deepsecurity.rest import ApiException
+from dsmigrator.logging import console
 from dsmigrator.api_config import AMConfigApiInstance
 from dsmigrator.migrator_utils import (
     validate_create,
@@ -66,7 +68,7 @@ def AMconfigtenant1(antimalwareconfig, url_link_final, tenant1key):
     directorylist = []
     fileextentionlist = []
     filelist = []
-    print("Getting Anti-Malware configuration from Tenant 1", flush=True)
+    console.log("Getting Anti-Malware configuration from Tenant 1")
     for count, amconfig in enumerate(antimalwareconfig):
         if int(amconfig) != 0:
             payload = {}
@@ -92,24 +94,22 @@ def AMconfigtenant1(antimalwareconfig, url_link_final, tenant1key):
             json_to_list(describe_json, "excludedFileListID", filelist)
             json_to_list(describe_json, "fileListID", filelist)
             json_to_list(describe_json, "excludedProcessImageFileListID", filelist)
-            print(
-                "#" + str(count) + " Anti-Malware Config ID: " + str(amconfig),
-                flush=True,
-            )
+            console.log("#" + str(count) + " Anti-Malware Config ID: " + str(amconfig))
     directorylist = list(dict.fromkeys(directorylist))
     fileextentionlist = list(dict.fromkeys(fileextentionlist))
     filelist = list(dict.fromkeys(filelist))
+    console.save_text("./duh")
     return directorylist, fileextentionlist, filelist, allamconfig
 
 
 def AmconfigTenant2(allamconfig, NEW_API_KEY):
-    print("Creating Anti-Malware Configuration in Tenant2", flush=True)
+    console.log("Creating Anti-Malware Configuration in Tenant2")
     if allamconfig:
         allamconfigdict = validate_create_dict(
             allamconfig, AMConfigApiInstance(NEW_API_KEY), "anti malware"
         )
-    print("New AM Config Dict", flush=True)
-    print(allamconfigdict, flush=True)
+    console.log("New AM Config Dict")
+    console.log(allamconfigdict)
     allamconfigdict[0] = 0
     return allamconfigdict
 
@@ -196,7 +196,7 @@ def RenameAmConfig(allamconfig):
     if allamconfig:
         for describe in allamconfig:
             amjson = json.loads(describe)
-            print(describe)
+            console.log(describe)
             amjson["name"] = amjson["name"] + " - Migrated"
             allamconfig[count] = json.dumps(amjson)
             count = count + 1
